.. This document was automatically generated.
   DO NOT EDIT!

:mod:`regexstream` Module
=========================

.. automodule:: wpull.regexstream
    :members:
    :show-inheritance:
    :private-members:
    :special-members:
    :exclude-members: __dict__,__weakref__
